# coding: utf-8
from __future__ import unicode_literals

from report_writer.core.content.base import BaseContent


try:
    from typing import TYPE_CHECKING
except ImportError:
    TYPE_CHECKING = False

if TYPE_CHECKING:
    from typing import Any


class StaticContent(BaseContent):
    """
    Статичный контент.

    .. code-block:: python

        content = StaticContent('foo')
        content.render(1)  # 'foo'
        content.render('foo')  # 'foo'
        content.render('bar')  # 'foo'

    :param content: Статичные данные
    """
    def __init__(self,
                 content=None  # type: Any
                 ):  # type: (...) -> None
        self._content = content  # type: Any

    def render(self,
               context=None  # type: Any
               ):  # type: (...) -> Any
        return self._content


class NoneContent(StaticContent):
    """
    None контент.

    .. code-block:: python

        content = NoneContent()
        content.render(1)  # None
        content.render('foo')  # None
        content.render('bar')  # None

    """
    def __init__(self
                 ):  # type: () -> None
        super(NoneContent, self).__init__(None)
