# coding: utf-8
from __future__ import unicode_literals

import abc

import six


try:
    from typing import TYPE_CHECKING
except ImportError:
    TYPE_CHECKING = False

if TYPE_CHECKING:
    from typing import Any


@six.add_metaclass(abc.ABCMeta)
class BaseWriter(object):
    """
    Базовый класс-писатель для отчёта.

    Используется как точка взаимодействия библиотеки с библиотеками
    использующимися для записи отчёта.

    Как правило используется внутри простых объектов отчёта, но может быть
    использован отдельно.
    """
    @abc.abstractmethod
    def write(self,
              row,  # type: int
              col,  # type: int
              data,  # type: Any
              ):  # type: (...) -> None
        """
        Запись данных в отчёт.

        :param row: Индекс строки для записи
        :param col: Индекс колонки для записи
        :param data: Данные для записи
        """
        raise NotImplementedError
