# coding: utf-8
from __future__ import unicode_literals


try:
    from typing import TYPE_CHECKING
except ImportError:
    TYPE_CHECKING = False

if TYPE_CHECKING:
    from typing import Any
    from typing import Iterable
    from typing import Iterator
    from typing import Tuple


def with_next(iterator,  # type: Iterable[Any]
              none=None  # type: Any
              ):  # type: (...) -> Iterator[Tuple[Any, Any]]
    """
    Итератор возвращающий пары значений (текущий, следующий)
    из переданного итератора.

    Следует учитывать что переданный итератор будет читаться "наперёд"

    Например если передать itertools.groupby то все группы будут пусты,
    т.к. для получения следующей группы нужно полностью пройти предыдущую,
    поэтому следует "сохранять" группы, при использование данного итератора

    :param iterator: Итератор
    :param none: Пустой объект, который вернётся в качестве следующего
                 в конце итерации
    :return: Итератор по парам (текущий, следующий)
    """
    current = none
    for value in iterator:
        if current is not none:
            yield (current, value)

        current = value

    if current is not none:
        yield (current, none)
